package de.unikassel.ir;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Collection;
import java.util.HashSet;
import java.util.Set;
import org.apache.log4j.Logger;
import de.unikassel.ir.vsr.Corpus;
import de.unikassel.ir.vsr.CorpusImpl;
import de.unikassel.ir.vsr.Document;
import de.unikassel.ir.vsr.DocumentImpl;

/**
 * Search Engine Bean um Methoden für JSPs sichtbar zu machen
 * @author Beate Krause
 */
public class SearchEngine {
	Logger log = Logger.getLogger(SearchEngine.class);
	
	/**
	 * Die Webseiten an sich
	 */
	private Corpus _corpus;

	/**
	 * Konstruktor lädt Default-Korpus 
	 */
	public SearchEngine() {
		_corpus = new CorpusImpl();
		loadDefaultCorpus();
	}
	
	/**
	 * Lädt den Texte Korpus
	 */
	public void loadDefaultCorpus() {
		
		//TODO: Anpassen - Verzeichnis mit Korpus
		File dir = new File("workspace_lehre/Programmieruebung-IR-09/resources/texte");

		for (File file : dir.listFiles()) {
			if (!file.isDirectory()) {
				FileInputStream stream;
				try {
					stream = new FileInputStream(file);
					Document doc = new DocumentImpl(file.getName());
					doc.read(stream);
					stream.close();
					_corpus.addDocument(doc);
				} catch (FileNotFoundException e) {
					e.printStackTrace();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
	}
	
	/**
	 * 
	 * @param terms Anfrage
	 * @param andOperator Entscheidet ob AND oder OR Anfrage, wenn mehrere Terme in der Anfrage enthalten sind
	 * @return
	 */
	public Set<String> testQuery(String terms, boolean andOperator) {
		
		String[] termsRequest = terms.split("\\s+");
		
		
		Set<String> resultIDs = new HashSet<String>();
		Collection<Document> docs;
		
		if (andOperator){
			docs = _corpus.getDocumentsContainingAll(termsRequest);
		}else{
			docs = _corpus.getDocumentsContainingAny(termsRequest);
		}
		
		for (Document doc : docs) {
			resultIDs.add(doc.getId());
		}
		
		return resultIDs;
	}
	
	/**
	 * @return der Corpus
	 */
	public Corpus getCorpus() {
		return _corpus;
	}
}
