/*
 * Created on 01.11.2005
 */
package de.unikassel.ir.vsr;

import java.util.Collection;
import java.util.Iterator;

/**
 * Reprsentiert eine Sammlung von Dokumenten.
 * 
 * @author Christoph Schmitz
 */
public interface Corpus extends Iterable<Document> {
	
	/**
	 * Fge ein Dokument in die Sammlung ein.
	 * 
	 * @param doc das einzufgende Dokument
	 */
	public void addDocument(Document doc);
	
	/**
	 * Liefert Iterator ber alle Dokumente.
	 * 
	 * @return Iterator ber alle Dokumente.
	 */
	public Iterator<Document> iterator();
	
	/**
	 * Liefert Dokumente, die alle genannten Terme enthalten (AND).
	 * 
	 * @param terms einer oder mehrere Terme
	 * @return Iterator ber alle Dokumente, die <em>alle</em> der Terme enthalten
	 */
	public Collection<Document> getDocumentsContainingAll(String... terms);
	
	/**
	 * Liefert Dokumente, die mindestens einen der genannten Terme enthalten (OR).
	 * 
	 * @param terms einer oder mehrere Terme
	 * @return Iterator ber alle Dokumente, die <em>mindestens einen</em> der Terme enthalten
	 */
	public Collection<Document> getDocumentsContainingAny(String... terms);

	/**
	 * Liefert die Gre (Anzahl Dokumente) des Korpus.
	 * 
	 * @return Anzahl der Dokumente im Korpus
	 */
	public int size();
}
